{% extends "base.html" %}
{% load static code %}

{% block title %}Connect your application · {{ site_title }}{% endblock %}

{% block content %}


<div class="flex items-center justify-center">

    <div class="m-4 max-w-4xl flex-auto">
        <h1 class="text-4xl font-bold">Connect your application</h1>

        <div class="mt-4">
            Connect your application to Bugsink to start tracking errors.
            Bugsink is compatible with the <a href="https://docs.sentry.io/platforms/">Sentry SDKs</a>.
            Use the following DSN to connect your application to Bugsink:
        </div>
{% code %}:::text
{{ dsn }}
{% endcode %}

        <h2 class="mt-8 text-2xl font-bold">Language-specific instructions</h2>
        <div class="mt-4">
            Pick your language to get specific instructions on how to set up the SDK. 

            <ul class="list-disc list-inside mt-4">
                <li><a class="text-cyan-500 font-bold" href="python/">Python</a></li>
                <li><a class="text-cyan-500 font-bold" href="javascript/">JavaScript</a></li>
                <li><a class="text-cyan-500 font-bold" href="php/">PHP</a></li>
            </ul>

        </div>
        <div class="mt-4">
            Not listed? It will probably work anyway! Just use the DSN above, and let us know if you run into any issues (or not).
        </div>

        <h2 class="mt-6 text-2xl font-bold">Further reading</h2>

        <div class="mt-4"> 
            For more information on how to use the SDK, check the <a href="https://www.bugsink.com/docs/sdk-recommendations/" class="text-cyan-500 font-bold">Bugsink-specific SDK recommendations</a>.
        </div>
        
    </div>
</div>

{% endblock %}
