# Generated by Django 4.2.16 on 2024-11-20 13:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("teams", "0002_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="team",
            name="visibility",
            field=models.IntegerField(
                choices=[(1, "Joinable"), (10, "Discoverable"), (99, "Hidden")],
                default=10,
                help_text="Which users can see this team and its issues?",
            ),
        ),
    ]
